Interface SafetykitClient
-
- All Implemented Interfaces:
public interface SafetykitClientA client for interacting with the Safetykit REST API synchronously. You can also switch to asynchronous execution via the async method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSafetykitClient.WithRawResponseA view of SafetykitClient that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SafetykitClientAsyncasync()Returns a version of this client that uses asynchronous execution. abstract SafetykitClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SafetykitClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract DataServicedata()Ingest data for fraud detection and risk analysis. abstract StreamServicestreams()Ingest and monitor livestream content. abstract AgentDecisionServiceagentDecisions()Send human reviewer final verdicts to SafetyKit. abstract Unitclose()Closes this client, relinquishing any underlying resources. -
-
Method Detail
-
async
abstract SafetykitClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract SafetykitClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SafetykitClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
data
abstract DataService data()
Ingest data for fraud detection and risk analysis.
-
streams
abstract StreamService streams()
Ingest and monitor livestream content.
-
agentDecisions
abstract AgentDecisionService agentDecisions()
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-