Package com.safetykit.client
Interface SafetykitClient.WithRawResponse
-
- All Implemented Interfaces:
public interface SafetykitClient.WithRawResponseA view of SafetykitClient that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SafetykitClient.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract DataService.WithRawResponsedata()Ingest data for fraud detection and risk analysis. abstract StreamService.WithRawResponsestreams()Ingest and monitor livestream content. abstract AgentDecisionService.WithRawResponseagentDecisions()Send human reviewer final verdicts to SafetyKit. abstract EventService.WithRawResponseevents()Ingest server-side product and trust-and-safety events for fraud detection and risk analysis. abstract ClientSessionService.WithRawResponseclientSessions()Create browser-safe webapp SDK session tokens from authenticated server-side code. -
-
Method Detail
-
withOptions
abstract SafetykitClient.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
data
abstract DataService.WithRawResponse data()
Ingest data for fraud detection and risk analysis.
-
streams
abstract StreamService.WithRawResponse streams()
Ingest and monitor livestream content.
-
agentDecisions
abstract AgentDecisionService.WithRawResponse agentDecisions()
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
events
abstract EventService.WithRawResponse events()
Ingest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
clientSessions
abstract ClientSessionService.WithRawResponse clientSessions()
Create browser-safe webapp SDK session tokens from authenticated server-side code.
-
-
-
-