Interface SafetykitClientAsync
-
- All Implemented Interfaces:
public interface SafetykitClientAsyncA client for interacting with the Safetykit REST API asynchronously. You can also switch to synchronous execution via the sync method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSafetykitClientAsync.WithRawResponseA view of SafetykitClientAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SafetykitClientsync()Returns a version of this client that uses synchronous execution. abstract SafetykitClientAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SafetykitClientAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract DataServiceAsyncdata()Ingest data for fraud detection and risk analysis. abstract StreamServiceAsyncstreams()Ingest and monitor livestream content. abstract AgentDecisionServiceAsyncagentDecisions()Send human reviewer final verdicts to SafetyKit. abstract EventServiceAsyncevents()Ingest server-side product and trust-and-safety events for fraud detection and risk analysis. abstract ClientSessionServiceAsyncclientSessions()Create browser-safe webapp SDK session tokens from authenticated server-side code. abstract Unitclose()Closes this client, relinquishing any underlying resources. -
-
Method Detail
-
sync
abstract SafetykitClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract SafetykitClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SafetykitClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
data
abstract DataServiceAsync data()
Ingest data for fraud detection and risk analysis.
-
streams
abstract StreamServiceAsync streams()
Ingest and monitor livestream content.
-
agentDecisions
abstract AgentDecisionServiceAsync agentDecisions()
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
events
abstract EventServiceAsync events()
Ingest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
clientSessions
abstract ClientSessionServiceAsync clientSessions()
Create browser-safe webapp SDK session tokens from authenticated server-side code.
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-