Package com.safetykit.client
Interface SafetykitClientAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface SafetykitClientAsync.WithRawResponseA view of SafetykitClientAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SafetykitClientAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract DataServiceAsync.WithRawResponsedata()Ingest data for fraud detection and risk analysis. abstract StreamServiceAsync.WithRawResponsestreams()Ingest and monitor livestream content. abstract AgentDecisionServiceAsync.WithRawResponseagentDecisions()Send human reviewer final verdicts to SafetyKit. -
-
Method Detail
-
withOptions
abstract SafetykitClientAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
data
abstract DataServiceAsync.WithRawResponse data()
Ingest data for fraud detection and risk analysis.
-
streams
abstract StreamServiceAsync.WithRawResponse streams()
Ingest and monitor livestream content.
-
agentDecisions
abstract AgentDecisionServiceAsync.WithRawResponse agentDecisions()
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
-
-
-