Class SafetykitClientAsyncImpl
-
- All Implemented Interfaces:
-
com.safetykit.client.SafetykitClientAsync
public final class SafetykitClientAsyncImpl implements SafetykitClientAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSafetykitClientAsyncImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description SafetykitClientAsyncImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description SafetykitClientsync()Returns a version of this client that uses synchronous execution. SafetykitClientAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SafetykitClientAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DataServiceAsyncdata()Ingest data for fraud detection and risk analysis. StreamServiceAsyncstreams()Ingest and monitor livestream content. AgentDecisionServiceAsyncagentDecisions()Send human reviewer final verdicts to SafetyKit. EventServiceAsyncevents()Ingest server-side product and trust-and-safety events for fraud detection and risk analysis. ClientSessionServiceAsyncclientSessions()Create browser-safe webapp SDK session tokens from authenticated server-side code. Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
SafetykitClientAsyncImpl
SafetykitClientAsyncImpl(ClientOptions clientOptions)
-
-
Method Detail
-
sync
SafetykitClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
SafetykitClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SafetykitClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
data
DataServiceAsync data()
Ingest data for fraud detection and risk analysis.
-
streams
StreamServiceAsync streams()
Ingest and monitor livestream content.
-
agentDecisions
AgentDecisionServiceAsync agentDecisions()
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
events
EventServiceAsync events()
Ingest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
clientSessions
ClientSessionServiceAsync clientSessions()
Create browser-safe webapp SDK session tokens from authenticated server-side code.
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-