Package com.safetykit.client
Class SafetykitClientAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.safetykit.client.SafetykitClientAsync.WithRawResponse
public final class SafetykitClientAsyncImpl.WithRawResponseImpl implements SafetykitClientAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SafetykitClientAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DataServiceAsync.WithRawResponsedata()Ingest data for fraud detection and risk analysis. StreamServiceAsync.WithRawResponsestreams()Ingest and monitor livestream content. AgentDecisionServiceAsync.WithRawResponseagentDecisions()Send human reviewer final verdicts to SafetyKit. EventServiceAsync.WithRawResponseevents()Ingest server-side product and trust-and-safety events for fraud detection and risk analysis. ClientSessionServiceAsync.WithRawResponseclientSessions()Create browser-safe webapp SDK session tokens from authenticated server-side code. -
-
Method Detail
-
withOptions
SafetykitClientAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
data
DataServiceAsync.WithRawResponse data()
Ingest data for fraud detection and risk analysis.
-
streams
StreamServiceAsync.WithRawResponse streams()
Ingest and monitor livestream content.
-
agentDecisions
AgentDecisionServiceAsync.WithRawResponse agentDecisions()
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
events
EventServiceAsync.WithRawResponse events()
Ingest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
clientSessions
ClientSessionServiceAsync.WithRawResponse clientSessions()
Create browser-safe webapp SDK session tokens from authenticated server-side code.
-
-
-
-