Class SafetykitClientImpl

    • Constructor Detail

      • SafetykitClientImpl

        SafetykitClientImpl(ClientOptions clientOptions)
    • Method Detail

      • async

         SafetykitClientAsync async()

        Returns a version of this client that uses asynchronous execution.

        The returned client shares its resources, like its connection pool and thread pools, with this client.

      • data

         DataService data()

        Ingest data for fraud detection and risk analysis.

      • agentDecisions

         AgentDecisionService agentDecisions()

        Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.

      • events

         EventService events()

        Ingest server-side product and trust-and-safety events for fraud detection and risk analysis.

      • close

         Unit close()

        Closes this client, relinquishing any underlying resources.

        This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.

        It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.