Package com.safetykit.client.okhttp
Class SafetykitOkHttpClient
-
- All Implemented Interfaces:
public final class SafetykitOkHttpClientA class that allows building an instance of SafetykitClient with OkHttpClient as the underlying HttpClient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSafetykitOkHttpClient.BuilderA builder for SafetykitOkHttpClient.
-
Method Summary
Modifier and Type Method Description final static SafetykitOkHttpClient.Builderbuilder()Returns a mutable builder for constructing an instance of SafetykitClient. final static SafetykitClientfromEnv()Returns a client configured using system properties and environment variables. -
-
Method Detail
-
builder
final static SafetykitOkHttpClient.Builder builder()
Returns a mutable builder for constructing an instance of SafetykitClient.
-
fromEnv
final static SafetykitClient fromEnv()
Returns a client configured using system properties and environment variables.
-
-
-
-