Package com.safetykit.client.okhttp
Class SafetykitOkHttpClientAsync
-
- All Implemented Interfaces:
public final class SafetykitOkHttpClientAsyncA class that allows building an instance of SafetykitClientAsync with OkHttpClient as the underlying HttpClient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSafetykitOkHttpClientAsync.BuilderA builder for SafetykitOkHttpClientAsync.
-
Method Summary
Modifier and Type Method Description final static SafetykitOkHttpClientAsync.Builderbuilder()Returns a mutable builder for constructing an instance of SafetykitClientAsync. final static SafetykitClientAsyncfromEnv()Returns a client configured using system properties and environment variables. -
-
Method Detail
-
builder
final static SafetykitOkHttpClientAsync.Builder builder()
Returns a mutable builder for constructing an instance of SafetykitClientAsync.
-
fromEnv
final static SafetykitClientAsync fromEnv()
Returns a client configured using system properties and environment variables.
-
-
-
-