Package com.safetykit.client
See: Description
-
Interface Summary Interface Description WithRawResponse A view of SafetykitClient that provides access to raw HTTP responses for each method. SafetykitClient A client for interacting with the Safetykit REST API synchronously. WithRawResponse A view of SafetykitClientAsync that provides access to raw HTTP responses for each method. SafetykitClientAsync A client for interacting with the Safetykit REST API asynchronously. -
Class Summary Class Description WithRawResponseImpl SafetykitClientAsyncImpl WithRawResponseImpl SafetykitClientImpl