Class ClientSessionCreateSessionParams
-
- All Implemented Interfaces:
-
com.safetykit.core.Params
public final class ClientSessionCreateSessionParams implements Params
Create a browser-safe SafetyKit webapp SDK session token from server-side code before rendering pages that load the browser SDK. The request must be authenticated with a valid Bearer token.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClientSessionCreateSessionParams.BuilderA builder for ClientSessionCreateSessionParams.
public final classClientSessionCreateSessionParams.BodyRequest body for creating a browser-safe webapp SDK session token from server-side code.
-
Method Summary
Modifier and Type Method Description final Optional<String>customerSessionHash()Hashed customer browser session value associated with the browser SDK session. final Optional<String>customerUserId()Customer user identifier associated with the browser SDK session. final JsonField<String>_customerSessionHash()Returns the raw JSON value of customerSessionHash. final JsonField<String>_customerUserId()Returns the raw JSON value of customerUserId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ClientSessionCreateSessionParams.BuildertoBuilder()final ClientSessionCreateSessionParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ClientSessionCreateSessionParamsnone()final static ClientSessionCreateSessionParams.Builderbuilder()Returns a mutable builder for constructing an instance of ClientSessionCreateSessionParams. -
-
Method Detail
-
customerSessionHash
final Optional<String> customerSessionHash()
Hashed customer browser session value associated with the browser SDK session.
-
customerUserId
final Optional<String> customerUserId()
Customer user identifier associated with the browser SDK session.
-
_customerSessionHash
final JsonField<String> _customerSessionHash()
Returns the raw JSON value of customerSessionHash.
Unlike customerSessionHash, this method doesn't throw if the JSON field has an unexpected type.
-
_customerUserId
final JsonField<String> _customerUserId()
Returns the raw JSON value of customerUserId.
Unlike customerUserId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ClientSessionCreateSessionParams.Builder toBuilder()
-
_body
final ClientSessionCreateSessionParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ClientSessionCreateSessionParams none()
-
builder
final static ClientSessionCreateSessionParams.Builder builder()
Returns a mutable builder for constructing an instance of ClientSessionCreateSessionParams.
-
-
-
-