Class ClientSessionCreateSessionParams.Body
-
- All Implemented Interfaces:
public final class ClientSessionCreateSessionParams.BodyRequest body for creating a browser-safe webapp SDK session token from server-side code.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClientSessionCreateSessionParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>customerSessionHash()Hashed customer browser session value associated with the browser SDK session. final Optional<String>customerUserId()Customer user identifier associated with the browser SDK session. final JsonField<String>_customerSessionHash()Returns the raw JSON value of customerSessionHash. final JsonField<String>_customerUserId()Returns the raw JSON value of customerUserId. final Map<String, JsonValue>_additionalProperties()final ClientSessionCreateSessionParams.Body.BuildertoBuilder()final ClientSessionCreateSessionParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ClientSessionCreateSessionParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
customerSessionHash
final Optional<String> customerSessionHash()
Hashed customer browser session value associated with the browser SDK session.
-
customerUserId
final Optional<String> customerUserId()
Customer user identifier associated with the browser SDK session.
-
_customerSessionHash
final JsonField<String> _customerSessionHash()
Returns the raw JSON value of customerSessionHash.
Unlike customerSessionHash, this method doesn't throw if the JSON field has an unexpected type.
-
_customerUserId
final JsonField<String> _customerUserId()
Returns the raw JSON value of customerUserId.
Unlike customerUserId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ClientSessionCreateSessionParams.Body.Builder toBuilder()
-
validate
final ClientSessionCreateSessionParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ClientSessionCreateSessionParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-