Class ClientSessionCreateSessionParams.Body.Builder
-
- All Implemented Interfaces:
public final class ClientSessionCreateSessionParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
customerSessionHash
final ClientSessionCreateSessionParams.Body.Builder customerSessionHash(String customerSessionHash)
Hashed customer browser session value associated with the browser SDK session.
-
customerSessionHash
final ClientSessionCreateSessionParams.Body.Builder customerSessionHash(JsonField<String> customerSessionHash)
Sets Builder.customerSessionHash to an arbitrary JSON value.
You should usually call Builder.customerSessionHash with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerUserId
final ClientSessionCreateSessionParams.Body.Builder customerUserId(String customerUserId)
Customer user identifier associated with the browser SDK session.
-
customerUserId
final ClientSessionCreateSessionParams.Body.Builder customerUserId(JsonField<String> customerUserId)
Sets Builder.customerUserId to an arbitrary JSON value.
You should usually call Builder.customerUserId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ClientSessionCreateSessionParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ClientSessionCreateSessionParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ClientSessionCreateSessionParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ClientSessionCreateSessionParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ClientSessionCreateSessionParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ClientSessionCreateSessionParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-