Class ClientSessionCreateSessionResponse
-
- All Implemented Interfaces:
public final class ClientSessionCreateSessionResponseResponse containing the browser-safe webapp SDK session token.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClientSessionCreateSessionResponse.BuilderA builder for ClientSessionCreateSessionResponse.
-
Method Summary
Modifier and Type Method Description final StringsessionToken()Browser-safe webapp SDK session token to pass to the browser SDK. final JsonField<String>_sessionToken()Returns the raw JSON value of sessionToken. final Map<String, JsonValue>_additionalProperties()final ClientSessionCreateSessionResponse.BuildertoBuilder()final ClientSessionCreateSessionResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ClientSessionCreateSessionResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ClientSessionCreateSessionResponse. -
-
Method Detail
-
sessionToken
final String sessionToken()
Browser-safe webapp SDK session token to pass to the browser SDK.
-
_sessionToken
final JsonField<String> _sessionToken()
Returns the raw JSON value of sessionToken.
Unlike sessionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ClientSessionCreateSessionResponse.Builder toBuilder()
-
validate
final ClientSessionCreateSessionResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ClientSessionCreateSessionResponse.Builder builder()
Returns a mutable builder for constructing an instance of ClientSessionCreateSessionResponse.
The following fields are required:
.sessionToken()
-
-
-
-