Class DataAddParams
-
- All Implemented Interfaces:
-
com.safetykit.core.Params
public final class DataAddParams implements Params
Add data to a namespace, returning immediately. Processing happens asynchronously in the background.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataAddParams.BuilderA builder for DataAddParams.
public final classDataAddParams.BodyRequest body for adding data to a namespace. Data is processed asynchronously after submission. You can submit a single object or an array of objects.
public final classDataAddParams.DataA data object to ingest. It must include an id field. All other fields are flexible and can be any JSON type.
-
Method Summary
Modifier and Type Method Description final Optional<String>namespace()The namespace to ingest data into final DataAddParams.Datadata()A data object to ingest. final JsonField<DataAddParams.Data>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final DataAddParams.BuildertoBuilder()final DataAddParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataAddParams.Builderbuilder()Returns a mutable builder for constructing an instance of DataAddParams. -
-
Method Detail
-
data
final DataAddParams.Data data()
A data object to ingest. It must include an id field. All other fields are flexible and can be any JSON type.
-
_data
final JsonField<DataAddParams.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DataAddParams.Builder toBuilder()
-
_body
final DataAddParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static DataAddParams.Builder builder()
Returns a mutable builder for constructing an instance of DataAddParams.
The following fields are required:
.data()
-
-
-
-