Package com.safetykit.models.data
Class DataAddParams.Body
-
- All Implemented Interfaces:
public final class DataAddParams.BodyRequest body for adding data to a namespace. Data is processed asynchronously after submission. You can submit a single object or an array of objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataAddParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final DataAddParams.Datadata()A data object to ingest. final JsonField<DataAddParams.Data>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final DataAddParams.Body.BuildertoBuilder()final DataAddParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataAddParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
data
final DataAddParams.Data data()
A data object to ingest. It must include an id field. All other fields are flexible and can be any JSON type.
-
_data
final JsonField<DataAddParams.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataAddParams.Body.Builder toBuilder()
-
validate
final DataAddParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataAddParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.data()
-
-
-
-