Class DataAddResponse
-
- All Implemented Interfaces:
public final class DataAddResponseResponse confirming data was accepted for asynchronous processing. The requestId can be used for debugging and tracking.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataAddResponse.BuilderA builder for DataAddResponse.
public final classDataAddResponse.StatusRequest was accepted for processing
-
Method Summary
Modifier and Type Method Description final StringrequestId()Unique identifier for tracking this request. final DataAddResponse.Statusstatus()Request was accepted for processing final JsonField<String>_requestId()Returns the raw JSON value of requestId. final JsonField<DataAddResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final DataAddResponse.BuildertoBuilder()final DataAddResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataAddResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DataAddResponse. -
-
Method Detail
-
requestId
final String requestId()
Unique identifier for tracking this request. Data processing happens asynchronously after this response.
-
status
final DataAddResponse.Status status()
Request was accepted for processing
-
_requestId
final JsonField<String> _requestId()
Returns the raw JSON value of requestId.
Unlike requestId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<DataAddResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataAddResponse.Builder toBuilder()
-
validate
final DataAddResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataAddResponse.Builder builder()
Returns a mutable builder for constructing an instance of DataAddResponse.
The following fields are required:
.requestId() .status()
-
-
-
-