Class DataCreateUploadUrlParams
-
- All Implemented Interfaces:
-
com.safetykit.core.Params
public final class DataCreateUploadUrlParams implements Params
Request a pre-signed upload URL for large JSONL batches into a namespace. After receiving
upload_url, upload your JSONL file usingPUT {upload_url}with headerContent-Type: application/json; put each JSON object on a new line.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataCreateUploadUrlParams.BuilderA builder for DataCreateUploadUrlParams.
public final classDataCreateUploadUrlParams.BodyRequest an upload URL for large JSONL batches. Send an empty JSON object if the namespace schema has already been configured, or include
schemato create or replace the namespace schema before upload.public final classDataCreateUploadUrlParams.SchemaSchema mapping field names to their definitions. Use content_type to specify which fields contain URLs that should be processed (images, videos, or websites), datetime fields, or 'metadata' for fields that should be stored but not indexed. Use display_hint to provide UI rendering hints.
-
Method Summary
Modifier and Type Method Description final Optional<String>namespace()The namespace to ingest data into final Optional<DataCreateUploadUrlParams.Schema>schema()Schema mapping field names to their definitions. final JsonField<DataCreateUploadUrlParams.Schema>_schema()Returns the raw JSON value of schema. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final DataCreateUploadUrlParams.BuildertoBuilder()final DataCreateUploadUrlParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataCreateUploadUrlParamsnone()final static DataCreateUploadUrlParams.Builderbuilder()Returns a mutable builder for constructing an instance of DataCreateUploadUrlParams. -
-
Method Detail
-
schema
final Optional<DataCreateUploadUrlParams.Schema> schema()
Schema mapping field names to their definitions. Use content_type to specify which fields contain URLs that should be processed (images, videos, or websites), datetime fields, or 'metadata' for fields that should be stored but not indexed. Use display_hint to provide UI rendering hints.
-
_schema
final JsonField<DataCreateUploadUrlParams.Schema> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DataCreateUploadUrlParams.Builder toBuilder()
-
_body
final DataCreateUploadUrlParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static DataCreateUploadUrlParams none()
-
builder
final static DataCreateUploadUrlParams.Builder builder()
Returns a mutable builder for constructing an instance of DataCreateUploadUrlParams.
-
-
-
-