Class DataCreateUploadUrlParams.Body

  • All Implemented Interfaces:

    
    public final class DataCreateUploadUrlParams.Body
    
                        

    Request an upload URL for large JSONL batches. Send an empty JSON object if the namespace schema has already been configured, or include schema to create or replace the namespace schema before upload.