Package com.safetykit.models.data
Class DataCreateUploadUrlParams.Schema
-
- All Implemented Interfaces:
public final class DataCreateUploadUrlParams.SchemaSchema mapping field names to their definitions. Use content_type to specify which fields contain URLs that should be processed (images, videos, or websites), datetime fields, or 'metadata' for fields that should be stored but not indexed. Use display_hint to provide UI rendering hints.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataCreateUploadUrlParams.Schema.BuilderA builder for Schema.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final DataCreateUploadUrlParams.Schema.BuildertoBuilder()final DataCreateUploadUrlParams.Schemavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataCreateUploadUrlParams.Schema.Builderbuilder()Returns a mutable builder for constructing an instance of Schema. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataCreateUploadUrlParams.Schema.Builder toBuilder()
-
validate
final DataCreateUploadUrlParams.Schema validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataCreateUploadUrlParams.Schema.Builder builder()
Returns a mutable builder for constructing an instance of Schema.
-
-
-
-