Class DataCreateUploadUrlResponse
-
- All Implemented Interfaces:
public final class DataCreateUploadUrlResponseResponse containing an upload URL and metadata for large-batch file processing. Use
PUT {upload_url}to upload JSONL (one JSON object per line).upload_urlexpires in 12 hours.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataCreateUploadUrlResponse.BuilderA builder for DataCreateUploadUrlResponse.
public final classDataCreateUploadUrlResponse.StatusRequest is waiting for file upload
-
Method Summary
Modifier and Type Method Description final StringexpiresAt()ISO timestamp when upload_url expires (12 hours after issuance) final StringobjectKey()S3 object key where uploaded JSONL will be processed from final StringrequestId()Unique identifier for this upload request final DataCreateUploadUrlResponse.Statusstatus()Request is waiting for file upload final StringuploadUrl()Pre-signed upload URL for PUT-ing JSONL content ( Content-Type: application/json)final JsonField<String>_expiresAt()Returns the raw JSON value of expiresAt. final JsonField<String>_objectKey()Returns the raw JSON value of objectKey. final JsonField<String>_requestId()Returns the raw JSON value of requestId. final JsonField<DataCreateUploadUrlResponse.Status>_status()Returns the raw JSON value of status. final JsonField<String>_uploadUrl()Returns the raw JSON value of uploadUrl. final Map<String, JsonValue>_additionalProperties()final DataCreateUploadUrlResponse.BuildertoBuilder()final DataCreateUploadUrlResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataCreateUploadUrlResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DataCreateUploadUrlResponse. -
-
Method Detail
-
status
final DataCreateUploadUrlResponse.Status status()
Request is waiting for file upload
-
uploadUrl
final String uploadUrl()
Pre-signed upload URL for PUT-ing JSONL content (
Content-Type: application/json)
-
_expiresAt
final JsonField<String> _expiresAt()
Returns the raw JSON value of expiresAt.
Unlike expiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_objectKey
final JsonField<String> _objectKey()
Returns the raw JSON value of objectKey.
Unlike objectKey, this method doesn't throw if the JSON field has an unexpected type.
-
_requestId
final JsonField<String> _requestId()
Returns the raw JSON value of requestId.
Unlike requestId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<DataCreateUploadUrlResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadUrl
final JsonField<String> _uploadUrl()
Returns the raw JSON value of uploadUrl.
Unlike uploadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataCreateUploadUrlResponse.Builder toBuilder()
-
validate
final DataCreateUploadUrlResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataCreateUploadUrlResponse.Builder builder()
Returns a mutable builder for constructing an instance of DataCreateUploadUrlResponse.
The following fields are required:
.expiresAt() .objectKey() .requestId() .status() .uploadUrl()
-
-
-
-