Class DataCreateUploadUrlResponse.Builder
-
- All Implemented Interfaces:
public final class DataCreateUploadUrlResponse.BuilderA builder for DataCreateUploadUrlResponse.
-
-
Method Summary
-
-
Method Detail
-
expiresAt
final DataCreateUploadUrlResponse.Builder expiresAt(String expiresAt)
ISO timestamp when upload_url expires (12 hours after issuance)
-
expiresAt
final DataCreateUploadUrlResponse.Builder expiresAt(JsonField<String> expiresAt)
Sets Builder.expiresAt to an arbitrary JSON value.
You should usually call Builder.expiresAt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
objectKey
final DataCreateUploadUrlResponse.Builder objectKey(String objectKey)
S3 object key where uploaded JSONL will be processed from
-
objectKey
final DataCreateUploadUrlResponse.Builder objectKey(JsonField<String> objectKey)
Sets Builder.objectKey to an arbitrary JSON value.
You should usually call Builder.objectKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requestId
final DataCreateUploadUrlResponse.Builder requestId(String requestId)
Unique identifier for this upload request
-
requestId
final DataCreateUploadUrlResponse.Builder requestId(JsonField<String> requestId)
Sets Builder.requestId to an arbitrary JSON value.
You should usually call Builder.requestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final DataCreateUploadUrlResponse.Builder status(DataCreateUploadUrlResponse.Status status)
Request is waiting for file upload
-
status
final DataCreateUploadUrlResponse.Builder status(JsonField<DataCreateUploadUrlResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uploadUrl
final DataCreateUploadUrlResponse.Builder uploadUrl(String uploadUrl)
Pre-signed upload URL for PUT-ing JSONL content (
Content-Type: application/json)
-
uploadUrl
final DataCreateUploadUrlResponse.Builder uploadUrl(JsonField<String> uploadUrl)
Sets Builder.uploadUrl to an arbitrary JSON value.
You should usually call Builder.uploadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DataCreateUploadUrlResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DataCreateUploadUrlResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DataCreateUploadUrlResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DataCreateUploadUrlResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DataCreateUploadUrlResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DataCreateUploadUrlResponse build()
Returns an immutable instance of DataCreateUploadUrlResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.expiresAt() .objectKey() .requestId() .status() .uploadUrl()
-
-
-
-