Package com.safetykit.models.data
Class DataObject
-
- All Implemented Interfaces:
public final class DataObjectA data object to ingest. It must include an id field. All other fields are flexible and can be any JSON type.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataObject.BuilderA builder for DataObject.
-
Method Summary
Modifier and Type Method Description final Stringid()Unique identifier for this data object. final JsonField<String>_id()Returns the raw JSON value of id. final Map<String, JsonValue>_additionalProperties()final DataObject.BuildertoBuilder()final DataObjectvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataObject.Builderbuilder()Returns a mutable builder for constructing an instance of DataObject. -
-
Method Detail
-
id
final String id()
Unique identifier for this data object. This should be a meaningful identifier in the customer's system, as it is the main way to search for specific items between systems.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataObject.Builder toBuilder()
-
validate
final DataObject validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataObject.Builder builder()
Returns a mutable builder for constructing an instance of DataObject.
The following fields are required:
.id()
-
-
-
-