Class DataUpdateSettingsParams
-
- All Implemented Interfaces:
-
com.safetykit.core.Params
public final class DataUpdateSettingsParams implements Params
Create or replace settings for a namespace, primarily used to change the schema associated with the namespace.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataUpdateSettingsParams.BuilderA builder for DataUpdateSettingsParams.
public final classDataUpdateSettingsParams.BodyRequest body for creating or replacing a namespace configuration.
public final classDataUpdateSettingsParams.SchemaSchema mapping field names to their definitions. Use content_type to specify which fields contain URLs that should be processed (images, videos, or websites), datetime fields, or 'metadata' for fields that should be stored but not indexed. Use display_hint to provide UI rendering hints.
-
Method Summary
Modifier and Type Method Description final Optional<String>namespace()The namespace to ingest data into final DataUpdateSettingsParams.Schemaschema()Schema mapping field names to their definitions. final JsonField<DataUpdateSettingsParams.Schema>_schema()Returns the raw JSON value of schema. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final DataUpdateSettingsParams.BuildertoBuilder()final DataUpdateSettingsParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataUpdateSettingsParams.Builderbuilder()Returns a mutable builder for constructing an instance of DataUpdateSettingsParams. -
-
Method Detail
-
schema
final DataUpdateSettingsParams.Schema schema()
Schema mapping field names to their definitions. Use content_type to specify which fields contain URLs that should be processed (images, videos, or websites), datetime fields, or 'metadata' for fields that should be stored but not indexed. Use display_hint to provide UI rendering hints.
-
_schema
final JsonField<DataUpdateSettingsParams.Schema> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DataUpdateSettingsParams.Builder toBuilder()
-
_body
final DataUpdateSettingsParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static DataUpdateSettingsParams.Builder builder()
Returns a mutable builder for constructing an instance of DataUpdateSettingsParams.
The following fields are required:
.schema()
-
-
-
-