Class DataUpdateSettingsParams.Body
-
- All Implemented Interfaces:
public final class DataUpdateSettingsParams.BodyRequest body for creating or replacing a namespace configuration.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataUpdateSettingsParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final DataUpdateSettingsParams.Schemaschema()Schema mapping field names to their definitions. final JsonField<DataUpdateSettingsParams.Schema>_schema()Returns the raw JSON value of schema. final Map<String, JsonValue>_additionalProperties()final DataUpdateSettingsParams.Body.BuildertoBuilder()final DataUpdateSettingsParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataUpdateSettingsParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
schema
final DataUpdateSettingsParams.Schema schema()
Schema mapping field names to their definitions. Use content_type to specify which fields contain URLs that should be processed (images, videos, or websites), datetime fields, or 'metadata' for fields that should be stored but not indexed. Use display_hint to provide UI rendering hints.
-
_schema
final JsonField<DataUpdateSettingsParams.Schema> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataUpdateSettingsParams.Body.Builder toBuilder()
-
validate
final DataUpdateSettingsParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataUpdateSettingsParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.schema()
-
-
-
-