Package com.safetykit.models.data
Class DataUpdateSettingsParams.Schema
-
- All Implemented Interfaces:
public final class DataUpdateSettingsParams.SchemaSchema mapping field names to their definitions. Use content_type to specify which fields contain URLs that should be processed (images, videos, or websites), datetime fields, or 'metadata' for fields that should be stored but not indexed. Use display_hint to provide UI rendering hints.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataUpdateSettingsParams.Schema.BuilderA builder for Schema.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final DataUpdateSettingsParams.Schema.BuildertoBuilder()final DataUpdateSettingsParams.Schemavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataUpdateSettingsParams.Schema.Builderbuilder()Returns a mutable builder for constructing an instance of Schema. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataUpdateSettingsParams.Schema.Builder toBuilder()
-
validate
final DataUpdateSettingsParams.Schema validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataUpdateSettingsParams.Schema.Builder builder()
Returns a mutable builder for constructing an instance of Schema.
-
-
-
-