Package com.safetykit.models.data
Class DataUpdateSettingsResponse
-
- All Implemented Interfaces:
public final class DataUpdateSettingsResponseNamespace configuration was stored.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataUpdateSettingsResponse.BuilderA builder for DataUpdateSettingsResponse.
public final classDataUpdateSettingsResponse.Status
-
Method Summary
Modifier and Type Method Description final Stringnamespace()final DataUpdateSettingsResponse.Statusstatus()final JsonField<String>_namespace()Returns the raw JSON value of namespace. final JsonField<DataUpdateSettingsResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final DataUpdateSettingsResponse.BuildertoBuilder()final DataUpdateSettingsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataUpdateSettingsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DataUpdateSettingsResponse. -
-
Method Detail
-
status
final DataUpdateSettingsResponse.Status status()
-
_namespace
final JsonField<String> _namespace()
Returns the raw JSON value of namespace.
Unlike namespace, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<DataUpdateSettingsResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataUpdateSettingsResponse.Builder toBuilder()
-
validate
final DataUpdateSettingsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataUpdateSettingsResponse.Builder builder()
Returns a mutable builder for constructing an instance of DataUpdateSettingsResponse.
The following fields are required:
.namespace() .status()
-
-
-
-