Class StreamAddFrameParams
-
- All Implemented Interfaces:
-
com.safetykit.core.Params
public final class StreamAddFrameParams implements Params
Ingest a single livestream frame as an image data URI plus relative timestamp in milliseconds. The stream does not need to be created beforehand. Only image/jpeg, image/png, and image/webp are accepted. The decoded bytes must match the declared mime type, decode as a valid image, stay within 5 MB, and stay within 4096x4096 / 16,000,000 total pixels. Timestamps are relative milliseconds from stream start and must be unique and strictly increasing within a stream. Duplicate or out-of-order frame timestamps are accepted at the API boundary but ignored by downstream processing. This method returns immediately after the frame has been accepted for processing.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddFrameParams.BuilderA builder for StreamAddFrameParams.
public final classStreamAddFrameParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>namespace()The namespace to ingest stream data into final StringimageDataUri()A data URI containing a base64-encoded frame image. final StringstreamId()final Longtimestamp()final JsonField<String>_imageDataUri()Returns the raw JSON value of imageDataUri. final JsonField<String>_streamId()Returns the raw JSON value of streamId. final JsonField<Long>_timestamp()Returns the raw JSON value of timestamp. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final StreamAddFrameParams.BuildertoBuilder()final StreamAddFrameParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddFrameParams.Builderbuilder()Returns a mutable builder for constructing an instance of StreamAddFrameParams. -
-
Method Detail
-
imageDataUri
final String imageDataUri()
A data URI containing a base64-encoded frame image. Only image/jpeg, image/png, and image/webp are accepted. The decoded bytes must match the declared mime type, decode as a valid image, stay within 5 MB, and stay within 4096x4096 / 16,000,000 total pixels.
-
_imageDataUri
final JsonField<String> _imageDataUri()
Returns the raw JSON value of imageDataUri.
Unlike imageDataUri, this method doesn't throw if the JSON field has an unexpected type.
-
_streamId
final JsonField<String> _streamId()
Returns the raw JSON value of streamId.
Unlike streamId, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<Long> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final StreamAddFrameParams.Builder toBuilder()
-
_body
final StreamAddFrameParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static StreamAddFrameParams.Builder builder()
Returns a mutable builder for constructing an instance of StreamAddFrameParams.
The following fields are required:
.imageDataUri() .streamId() .timestamp()
-
-
-
-