Class StreamAddFrameParams.Body
-
- All Implemented Interfaces:
public final class StreamAddFrameParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddFrameParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringimageDataUri()A data URI containing a base64-encoded frame image. final StringstreamId()final Longtimestamp()final JsonField<String>_imageDataUri()Returns the raw JSON value of imageDataUri. final JsonField<String>_streamId()Returns the raw JSON value of streamId. final JsonField<Long>_timestamp()Returns the raw JSON value of timestamp. final Map<String, JsonValue>_additionalProperties()final StreamAddFrameParams.Body.BuildertoBuilder()final StreamAddFrameParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddFrameParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
imageDataUri
final String imageDataUri()
A data URI containing a base64-encoded frame image. Only image/jpeg, image/png, and image/webp are accepted. The decoded bytes must match the declared mime type, decode as a valid image, stay within 5 MB, and stay within 4096x4096 / 16,000,000 total pixels.
-
_imageDataUri
final JsonField<String> _imageDataUri()
Returns the raw JSON value of imageDataUri.
Unlike imageDataUri, this method doesn't throw if the JSON field has an unexpected type.
-
_streamId
final JsonField<String> _streamId()
Returns the raw JSON value of streamId.
Unlike streamId, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<Long> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamAddFrameParams.Body.Builder toBuilder()
-
validate
final StreamAddFrameParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamAddFrameParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.imageDataUri() .streamId() .timestamp()
-
-
-
-