Class StreamAddFrameParams.Body.Builder
-
- All Implemented Interfaces:
public final class StreamAddFrameParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
imageDataUri
final StreamAddFrameParams.Body.Builder imageDataUri(String imageDataUri)
A data URI containing a base64-encoded frame image. Only image/jpeg, image/png, and image/webp are accepted. The decoded bytes must match the declared mime type, decode as a valid image, stay within 5 MB, and stay within 4096x4096 / 16,000,000 total pixels.
-
imageDataUri
final StreamAddFrameParams.Body.Builder imageDataUri(JsonField<String> imageDataUri)
Sets Builder.imageDataUri to an arbitrary JSON value.
You should usually call Builder.imageDataUri with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
streamId
final StreamAddFrameParams.Body.Builder streamId(String streamId)
-
streamId
final StreamAddFrameParams.Body.Builder streamId(JsonField<String> streamId)
Sets Builder.streamId to an arbitrary JSON value.
You should usually call Builder.streamId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timestamp
final StreamAddFrameParams.Body.Builder timestamp(Long timestamp)
-
timestamp
final StreamAddFrameParams.Body.Builder timestamp(JsonField<Long> timestamp)
Sets Builder.timestamp to an arbitrary JSON value.
You should usually call Builder.timestamp with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final StreamAddFrameParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final StreamAddFrameParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final StreamAddFrameParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final StreamAddFrameParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final StreamAddFrameParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final StreamAddFrameParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.imageDataUri() .streamId() .timestamp()
-
-
-
-