Package com.safetykit.models.streams
Class StreamAddFrameResponse
-
- All Implemented Interfaces:
public final class StreamAddFrameResponseStream ingestion request accepted for asynchronous processing.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddFrameResponse.BuilderA builder for StreamAddFrameResponse.
public final classStreamAddFrameResponse.Status
-
Method Summary
Modifier and Type Method Description final StringrequestId()final StreamAddFrameResponse.Statusstatus()final JsonField<String>_requestId()Returns the raw JSON value of requestId. final JsonField<StreamAddFrameResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final StreamAddFrameResponse.BuildertoBuilder()final StreamAddFrameResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddFrameResponse.Builderbuilder()Returns a mutable builder for constructing an instance of StreamAddFrameResponse. -
-
Method Detail
-
status
final StreamAddFrameResponse.Status status()
-
_requestId
final JsonField<String> _requestId()
Returns the raw JSON value of requestId.
Unlike requestId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<StreamAddFrameResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamAddFrameResponse.Builder toBuilder()
-
validate
final StreamAddFrameResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamAddFrameResponse.Builder builder()
Returns a mutable builder for constructing an instance of StreamAddFrameResponse.
The following fields are required:
.requestId() .status()
-
-
-
-