Package com.safetykit.models.streams
Class StreamAddParams
-
- All Implemented Interfaces:
-
com.safetykit.core.Params
public final class StreamAddParams implements Params
Monitor the livestream at the given stream URL. This method returns immediately.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddParams.BuilderA builder for StreamAddParams.
public final classStreamAddParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>namespace()The namespace to ingest stream data into final Stringid()final StringstreamUrl()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_streamUrl()Returns the raw JSON value of streamUrl. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final StreamAddParams.BuildertoBuilder()final StreamAddParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddParams.Builderbuilder()Returns a mutable builder for constructing an instance of StreamAddParams. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_streamUrl
final JsonField<String> _streamUrl()
Returns the raw JSON value of streamUrl.
Unlike streamUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final StreamAddParams.Builder toBuilder()
-
_body
final StreamAddParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static StreamAddParams.Builder builder()
Returns a mutable builder for constructing an instance of StreamAddParams.
The following fields are required:
.id() .streamUrl()
-
-
-
-