Package com.safetykit.models.streams
Class StreamAddParams.Body
-
- All Implemented Interfaces:
public final class StreamAddParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringid()final StringstreamUrl()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_streamUrl()Returns the raw JSON value of streamUrl. final Map<String, JsonValue>_additionalProperties()final StreamAddParams.Body.BuildertoBuilder()final StreamAddParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_streamUrl
final JsonField<String> _streamUrl()
Returns the raw JSON value of streamUrl.
Unlike streamUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamAddParams.Body.Builder toBuilder()
-
validate
final StreamAddParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamAddParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.id() .streamUrl()
-
-
-
-