Package com.safetykit.models.streams
Class StreamAddResponse
-
- All Implemented Interfaces:
public final class StreamAddResponseStream ingestion request accepted for asynchronous processing.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddResponse.BuilderA builder for StreamAddResponse.
public final classStreamAddResponse.Status
-
Method Summary
Modifier and Type Method Description final StringrequestId()final StreamAddResponse.Statusstatus()final JsonField<String>_requestId()Returns the raw JSON value of requestId. final JsonField<StreamAddResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final StreamAddResponse.BuildertoBuilder()final StreamAddResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddResponse.Builderbuilder()Returns a mutable builder for constructing an instance of StreamAddResponse. -
-
Method Detail
-
status
final StreamAddResponse.Status status()
-
_requestId
final JsonField<String> _requestId()
Returns the raw JSON value of requestId.
Unlike requestId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<StreamAddResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamAddResponse.Builder toBuilder()
-
validate
final StreamAddResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamAddResponse.Builder builder()
Returns a mutable builder for constructing an instance of StreamAddResponse.
The following fields are required:
.requestId() .status()
-
-
-
-