Class StreamAddTranscriptParams

  • All Implemented Interfaces:
    com.safetykit.core.Params

    
    public final class StreamAddTranscriptParams
     implements Params
                        

    Ingest a single transcript segment for a livestream using a relative timestamp in milliseconds. The stream does not need to be created beforehand. Transcript timestamps are relative milliseconds from stream start and should be monotonically increasing within a stream so transcript context lines up correctly with later frames. This method returns immediately after the transcript has been accepted for processing.