Package com.safetykit.models.streams
Class StreamAddTranscriptParams.Body
-
- All Implemented Interfaces:
public final class StreamAddTranscriptParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddTranscriptParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringstreamId()final Stringtext()final Longtimestamp()final JsonField<String>_streamId()Returns the raw JSON value of streamId. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<Long>_timestamp()Returns the raw JSON value of timestamp. final Map<String, JsonValue>_additionalProperties()final StreamAddTranscriptParams.Body.BuildertoBuilder()final StreamAddTranscriptParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddTranscriptParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_streamId
final JsonField<String> _streamId()
Returns the raw JSON value of streamId.
Unlike streamId, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<Long> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamAddTranscriptParams.Body.Builder toBuilder()
-
validate
final StreamAddTranscriptParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamAddTranscriptParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.streamId() .text() .timestamp()
-
-
-
-