Class StreamAddTranscriptParams.Body.Builder
-
- All Implemented Interfaces:
public final class StreamAddTranscriptParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
streamId
final StreamAddTranscriptParams.Body.Builder streamId(String streamId)
-
streamId
final StreamAddTranscriptParams.Body.Builder streamId(JsonField<String> streamId)
Sets Builder.streamId to an arbitrary JSON value.
You should usually call Builder.streamId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final StreamAddTranscriptParams.Body.Builder text(String text)
-
text
final StreamAddTranscriptParams.Body.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timestamp
final StreamAddTranscriptParams.Body.Builder timestamp(Long timestamp)
-
timestamp
final StreamAddTranscriptParams.Body.Builder timestamp(JsonField<Long> timestamp)
Sets Builder.timestamp to an arbitrary JSON value.
You should usually call Builder.timestamp with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final StreamAddTranscriptParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final StreamAddTranscriptParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final StreamAddTranscriptParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final StreamAddTranscriptParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final StreamAddTranscriptParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final StreamAddTranscriptParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.streamId() .text() .timestamp()
-
-
-
-