Package com.safetykit.models.streams
Class StreamAddTranscriptResponse
-
- All Implemented Interfaces:
public final class StreamAddTranscriptResponseStream ingestion request accepted for asynchronous processing.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddTranscriptResponse.BuilderA builder for StreamAddTranscriptResponse.
public final classStreamAddTranscriptResponse.Status
-
Method Summary
Modifier and Type Method Description final StringrequestId()final StreamAddTranscriptResponse.Statusstatus()final JsonField<String>_requestId()Returns the raw JSON value of requestId. final JsonField<StreamAddTranscriptResponse.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final StreamAddTranscriptResponse.BuildertoBuilder()final StreamAddTranscriptResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddTranscriptResponse.Builderbuilder()Returns a mutable builder for constructing an instance of StreamAddTranscriptResponse. -
-
Method Detail
-
status
final StreamAddTranscriptResponse.Status status()
-
_requestId
final JsonField<String> _requestId()
Returns the raw JSON value of requestId.
Unlike requestId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<StreamAddTranscriptResponse.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StreamAddTranscriptResponse.Builder toBuilder()
-
validate
final StreamAddTranscriptResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StreamAddTranscriptResponse.Builder builder()
Returns a mutable builder for constructing an instance of StreamAddTranscriptResponse.
The following fields are required:
.requestId() .status()
-
-
-
-