Interface AgentDecisionServiceAsync
-
- All Implemented Interfaces:
public interface AgentDecisionServiceAsyncSend human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAgentDecisionServiceAsync.WithRawResponseA view of AgentDecisionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AgentDecisionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AgentDecisionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AgentDecisionCreateAgentDecisionResponse>createAgentDecision(AgentDecisionCreateAgentDecisionParams params)Record a human reviewer's final verdict for content that SafetyKit has previously reviewed. abstract CompletableFuture<AgentDecisionCreateAgentDecisionResponse>createAgentDecision(AgentDecisionCreateAgentDecisionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AgentDecisionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AgentDecisionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createAgentDecision
CompletableFuture<AgentDecisionCreateAgentDecisionResponse> createAgentDecision(AgentDecisionCreateAgentDecisionParams params)
Record a human reviewer's final verdict for content that SafetyKit has previously reviewed. This ground truth feedback allows SafetyKit to improve the accuracy of automated decisions. Each call provides feedback on whether a given piece of content violates a specific policy category. If content is reviewed for multiple policies, send one call per policy.
-
createAgentDecision
abstract CompletableFuture<AgentDecisionCreateAgentDecisionResponse> createAgentDecision(AgentDecisionCreateAgentDecisionParams params, RequestOptions requestOptions)
-
-
-
-