Package com.safetykit.services.async
Class AgentDecisionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.async.AgentDecisionServiceAsync
public final class AgentDecisionServiceAsyncImpl implements AgentDecisionServiceAsync
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentDecisionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AgentDecisionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AgentDecisionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AgentDecisionCreateAgentDecisionResponse>createAgentDecision(AgentDecisionCreateAgentDecisionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AgentDecisionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AgentDecisionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createAgentDecision
CompletableFuture<AgentDecisionCreateAgentDecisionResponse> createAgentDecision(AgentDecisionCreateAgentDecisionParams params, RequestOptions requestOptions)
-
-
-
-