Package com.safetykit.services.async
Interface ClientSessionServiceAsync
-
- All Implemented Interfaces:
public interface ClientSessionServiceAsyncCreate browser-safe webapp SDK session tokens from authenticated server-side code.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceClientSessionServiceAsync.WithRawResponseA view of ClientSessionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ClientSessionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ClientSessionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ClientSessionCreateSessionResponse>createSession()Create a browser-safe SafetyKit webapp SDK session token from server-side code before rendering pages that load the browser SDK. abstract CompletableFuture<ClientSessionCreateSessionResponse>createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)CompletableFuture<ClientSessionCreateSessionResponse>createSession(ClientSessionCreateSessionParams params)CompletableFuture<ClientSessionCreateSessionResponse>createSession(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ClientSessionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ClientSessionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createSession
CompletableFuture<ClientSessionCreateSessionResponse> createSession()
Create a browser-safe SafetyKit webapp SDK session token from server-side code before rendering pages that load the browser SDK. The request must be authenticated with a valid Bearer token.
-
createSession
abstract CompletableFuture<ClientSessionCreateSessionResponse> createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)
-
createSession
CompletableFuture<ClientSessionCreateSessionResponse> createSession(ClientSessionCreateSessionParams params)
-
createSession
CompletableFuture<ClientSessionCreateSessionResponse> createSession(RequestOptions requestOptions)
-
-
-
-