Package com.safetykit.services.async
Interface ClientSessionServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface ClientSessionServiceAsync.WithRawResponseA view of ClientSessionServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ClientSessionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>>createSession()Returns a raw HTTP response for post /v1/sessions, but is otherwise the same as ClientSessionServiceAsync.createSession.abstract CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>>createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>>createSession(ClientSessionCreateSessionParams params)CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>>createSession(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ClientSessionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createSession
CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>> createSession()
Returns a raw HTTP response for
post /v1/sessions, but is otherwise the same as ClientSessionServiceAsync.createSession.
-
createSession
abstract CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>> createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)
-
createSession
CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>> createSession(ClientSessionCreateSessionParams params)
-
createSession
CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>> createSession(RequestOptions requestOptions)
-
-
-
-