Package com.safetykit.services.async
Class ClientSessionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.async.ClientSessionServiceAsync
public final class ClientSessionServiceAsyncImpl implements ClientSessionServiceAsync
Create browser-safe webapp SDK session tokens from authenticated server-side code.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClientSessionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ClientSessionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ClientSessionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ClientSessionCreateSessionResponse>createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ClientSessionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ClientSessionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createSession
CompletableFuture<ClientSessionCreateSessionResponse> createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)
-
-
-
-