Package com.safetykit.services.async
Class ClientSessionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.async.ClientSessionServiceAsync.WithRawResponse
public final class ClientSessionServiceAsyncImpl.WithRawResponseImpl implements ClientSessionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ClientSessionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>>createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ClientSessionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createSession
CompletableFuture<HttpResponseFor<ClientSessionCreateSessionResponse>> createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)
-
-
-
-