Package com.safetykit.services.async
Class DataServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.async.DataServiceAsync
public final class DataServiceAsyncImpl implements DataServiceAsync
Ingest data for fraud detection and risk analysis.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DataServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DataServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<DataAddResponse>add(DataAddParams params, RequestOptions requestOptions)CompletableFuture<DataCreateUploadUrlResponse>createUploadUrl(DataCreateUploadUrlParams params, RequestOptions requestOptions)CompletableFuture<DataGetDownloadUrlResponse>getDownloadUrl(DataGetDownloadUrlParams params, RequestOptions requestOptions)CompletableFuture<DataGetStatusResponse>getStatus(DataGetStatusParams params, RequestOptions requestOptions)CompletableFuture<DataUpdateSettingsResponse>updateSettings(DataUpdateSettingsParams params, RequestOptions requestOptions)-
Methods inherited from class com.safetykit.services.async.DataServiceAsync
add, add, add, createUploadUrl, createUploadUrl, createUploadUrl, createUploadUrl, createUploadUrl, getDownloadUrl, getDownloadUrl, getDownloadUrl, getStatus, getStatus, getStatus, updateSettings, updateSettings, updateSettings -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DataServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DataServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
add
CompletableFuture<DataAddResponse> add(DataAddParams params, RequestOptions requestOptions)
-
createUploadUrl
CompletableFuture<DataCreateUploadUrlResponse> createUploadUrl(DataCreateUploadUrlParams params, RequestOptions requestOptions)
-
getDownloadUrl
CompletableFuture<DataGetDownloadUrlResponse> getDownloadUrl(DataGetDownloadUrlParams params, RequestOptions requestOptions)
-
getStatus
CompletableFuture<DataGetStatusResponse> getStatus(DataGetStatusParams params, RequestOptions requestOptions)
-
updateSettings
CompletableFuture<DataUpdateSettingsResponse> updateSettings(DataUpdateSettingsParams params, RequestOptions requestOptions)
-
-
-
-