Interface EventServiceAsync
-
- All Implemented Interfaces:
public interface EventServiceAsyncIngest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventServiceAsync.WithRawResponseA view of EventServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract EventServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EventServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createUploadUrl
CompletableFuture<EventCreateUploadUrlResponse> createUploadUrl()
Request a pre-signed upload URL for large JSONL event batches. After receiving
upload_url, upload your JSONL file usingPUT {upload_url}with headerContent-Type: application/jsonl+json; put each event object on a new line.
-
createUploadUrl
abstract CompletableFuture<EventCreateUploadUrlResponse> createUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)
-
createUploadUrl
CompletableFuture<EventCreateUploadUrlResponse> createUploadUrl(EventCreateUploadUrlParams params)
-
createUploadUrl
CompletableFuture<EventCreateUploadUrlResponse> createUploadUrl(RequestOptions requestOptions)
-
push
CompletableFuture<EventPushResponse> push(EventPushParams params)
Ingest server-side product or trust-and-safety events. This endpoint returns immediately after the events are accepted for asynchronous processing.
-
push
abstract CompletableFuture<EventPushResponse> push(EventPushParams params, RequestOptions requestOptions)
-
-
-
-