Package com.safetykit.services.async
Class EventServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.async.EventServiceAsync
public final class EventServiceAsyncImpl implements EventServiceAsync
Ingest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<EventCreateUploadUrlResponse>createUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)CompletableFuture<EventPushResponse>push(EventPushParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EventServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createUploadUrl
CompletableFuture<EventCreateUploadUrlResponse> createUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)
-
push
CompletableFuture<EventPushResponse> push(EventPushParams params, RequestOptions requestOptions)
-
-
-
-