Package com.safetykit.services.async
Class EventServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.async.EventServiceAsync.WithRawResponse
public final class EventServiceAsyncImpl.WithRawResponseImpl implements EventServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<EventCreateUploadUrlResponse>>createUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EventPushResponse>>push(EventPushParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
EventServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createUploadUrl
CompletableFuture<HttpResponseFor<EventCreateUploadUrlResponse>> createUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)
-
push
CompletableFuture<HttpResponseFor<EventPushResponse>> push(EventPushParams params, RequestOptions requestOptions)
-
-
-
-