Package com.safetykit.services.async
Class StreamServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.async.StreamServiceAsync
public final class StreamServiceAsyncImpl implements StreamServiceAsync
Ingest and monitor livestream content.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description StreamServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. StreamServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<StreamAddResponse>add(StreamAddParams params, RequestOptions requestOptions)CompletableFuture<StreamAddFrameResponse>addFrame(StreamAddFrameParams params, RequestOptions requestOptions)CompletableFuture<StreamAddTranscriptResponse>addTranscript(StreamAddTranscriptParams params, RequestOptions requestOptions)-
Methods inherited from class com.safetykit.services.async.StreamServiceAsync
add, add, add, addFrame, addFrame, addFrame, addTranscript, addTranscript, addTranscript -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
StreamServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
StreamServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
add
CompletableFuture<StreamAddResponse> add(StreamAddParams params, RequestOptions requestOptions)
-
addFrame
CompletableFuture<StreamAddFrameResponse> addFrame(StreamAddFrameParams params, RequestOptions requestOptions)
-
addTranscript
CompletableFuture<StreamAddTranscriptResponse> addTranscript(StreamAddTranscriptParams params, RequestOptions requestOptions)
-
-
-
-