Package com.safetykit.services.async
Class StreamServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.async.StreamServiceAsync.WithRawResponse
public final class StreamServiceAsyncImpl.WithRawResponseImpl implements StreamServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description StreamServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<StreamAddResponse>>add(StreamAddParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<StreamAddFrameResponse>>addFrame(StreamAddFrameParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<StreamAddTranscriptResponse>>addTranscript(StreamAddTranscriptParams params, RequestOptions requestOptions)-
Methods inherited from class com.safetykit.services.async.StreamServiceAsync.WithRawResponse
add, add, add, addFrame, addFrame, addFrame, addTranscript, addTranscript, addTranscript -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
StreamServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
add
CompletableFuture<HttpResponseFor<StreamAddResponse>> add(StreamAddParams params, RequestOptions requestOptions)
-
addFrame
CompletableFuture<HttpResponseFor<StreamAddFrameResponse>> addFrame(StreamAddFrameParams params, RequestOptions requestOptions)
-
addTranscript
CompletableFuture<HttpResponseFor<StreamAddTranscriptResponse>> addTranscript(StreamAddTranscriptParams params, RequestOptions requestOptions)
-
-
-
-