Package com.safetykit.services.blocking
Class AgentDecisionServiceImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.blocking.AgentDecisionService
public final class AgentDecisionServiceImpl implements AgentDecisionService
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAgentDecisionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AgentDecisionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AgentDecisionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AgentDecisionCreateAgentDecisionResponsecreateAgentDecision(AgentDecisionCreateAgentDecisionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AgentDecisionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AgentDecisionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createAgentDecision
AgentDecisionCreateAgentDecisionResponse createAgentDecision(AgentDecisionCreateAgentDecisionParams params, RequestOptions requestOptions)
-
-
-
-