Package com.safetykit.services.blocking
Interface ClientSessionService
-
- All Implemented Interfaces:
public interface ClientSessionServiceCreate browser-safe webapp SDK session tokens from authenticated server-side code.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceClientSessionService.WithRawResponseA view of ClientSessionService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ClientSessionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ClientSessionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ClientSessionCreateSessionResponsecreateSession()Create a browser-safe SafetyKit webapp SDK session token from server-side code before rendering pages that load the browser SDK. abstract ClientSessionCreateSessionResponsecreateSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)ClientSessionCreateSessionResponsecreateSession(ClientSessionCreateSessionParams params)ClientSessionCreateSessionResponsecreateSession(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ClientSessionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ClientSessionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createSession
ClientSessionCreateSessionResponse createSession()
Create a browser-safe SafetyKit webapp SDK session token from server-side code before rendering pages that load the browser SDK. The request must be authenticated with a valid Bearer token.
-
createSession
abstract ClientSessionCreateSessionResponse createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)
-
createSession
ClientSessionCreateSessionResponse createSession(ClientSessionCreateSessionParams params)
-
createSession
ClientSessionCreateSessionResponse createSession(RequestOptions requestOptions)
-
-
-
-