Package com.safetykit.services.blocking
Interface ClientSessionService.WithRawResponse
-
- All Implemented Interfaces:
public interface ClientSessionService.WithRawResponseA view of ClientSessionService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ClientSessionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<ClientSessionCreateSessionResponse>createSession()Returns a raw HTTP response for post /v1/sessions, but is otherwise the same as ClientSessionService.createSession.abstract HttpResponseFor<ClientSessionCreateSessionResponse>createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)HttpResponseFor<ClientSessionCreateSessionResponse>createSession(ClientSessionCreateSessionParams params)HttpResponseFor<ClientSessionCreateSessionResponse>createSession(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ClientSessionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createSession
@MustBeClosed() HttpResponseFor<ClientSessionCreateSessionResponse> createSession()
Returns a raw HTTP response for
post /v1/sessions, but is otherwise the same as ClientSessionService.createSession.
-
createSession
@MustBeClosed() abstract HttpResponseFor<ClientSessionCreateSessionResponse> createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)
-
createSession
@MustBeClosed() HttpResponseFor<ClientSessionCreateSessionResponse> createSession(ClientSessionCreateSessionParams params)
-
createSession
@MustBeClosed() HttpResponseFor<ClientSessionCreateSessionResponse> createSession(RequestOptions requestOptions)
-
-
-
-