Package com.safetykit.services.blocking
Class ClientSessionServiceImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.blocking.ClientSessionService
public final class ClientSessionServiceImpl implements ClientSessionService
Create browser-safe webapp SDK session tokens from authenticated server-side code.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClientSessionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ClientSessionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ClientSessionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ClientSessionCreateSessionResponsecreateSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ClientSessionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ClientSessionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createSession
ClientSessionCreateSessionResponse createSession(ClientSessionCreateSessionParams params, RequestOptions requestOptions)
-
-
-
-