Package com.safetykit.services.blocking
Interface EventService
-
- All Implemented Interfaces:
public interface EventServiceIngest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventService.WithRawResponseA view of EventService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EventServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EventCreateUploadUrlResponsecreateUploadUrl()Request a pre-signed upload URL for large JSONL event batches. abstract EventCreateUploadUrlResponsecreateUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)EventCreateUploadUrlResponsecreateUploadUrl(EventCreateUploadUrlParams params)EventCreateUploadUrlResponsecreateUploadUrl(RequestOptions requestOptions)EventPushResponsepush(EventPushParams params)Ingest server-side product or trust-and-safety events. abstract EventPushResponsepush(EventPushParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EventService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createUploadUrl
EventCreateUploadUrlResponse createUploadUrl()
Request a pre-signed upload URL for large JSONL event batches. After receiving
upload_url, upload your JSONL file usingPUT {upload_url}with headerContent-Type: application/jsonl+json; put each event object on a new line.
-
createUploadUrl
abstract EventCreateUploadUrlResponse createUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)
-
createUploadUrl
EventCreateUploadUrlResponse createUploadUrl(EventCreateUploadUrlParams params)
-
createUploadUrl
EventCreateUploadUrlResponse createUploadUrl(RequestOptions requestOptions)
-
push
EventPushResponse push(EventPushParams params)
Ingest server-side product or trust-and-safety events. This endpoint returns immediately after the events are accepted for asynchronous processing.
-
push
abstract EventPushResponse push(EventPushParams params, RequestOptions requestOptions)
-
-
-
-