Package com.safetykit.services.blocking
Class EventServiceImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.blocking.EventService
public final class EventServiceImpl implements EventService
Ingest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EventCreateUploadUrlResponsecreateUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)EventPushResponsepush(EventPushParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
createUploadUrl
EventCreateUploadUrlResponse createUploadUrl(EventCreateUploadUrlParams params, RequestOptions requestOptions)
-
push
EventPushResponse push(EventPushParams params, RequestOptions requestOptions)
-
-
-
-