Package com.safetykit.services.blocking
Class StreamServiceImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.blocking.StreamService
public final class StreamServiceImpl implements StreamService
Ingest and monitor livestream content.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description StreamService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. StreamServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. StreamAddResponseadd(StreamAddParams params, RequestOptions requestOptions)StreamAddFrameResponseaddFrame(StreamAddFrameParams params, RequestOptions requestOptions)StreamAddTranscriptResponseaddTranscript(StreamAddTranscriptParams params, RequestOptions requestOptions)-
Methods inherited from class com.safetykit.services.blocking.StreamService
add, add, add, addFrame, addFrame, addFrame, addTranscript, addTranscript, addTranscript -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
StreamService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
StreamService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
add
StreamAddResponse add(StreamAddParams params, RequestOptions requestOptions)
-
addFrame
StreamAddFrameResponse addFrame(StreamAddFrameParams params, RequestOptions requestOptions)
-
addTranscript
StreamAddTranscriptResponse addTranscript(StreamAddTranscriptParams params, RequestOptions requestOptions)
-
-
-
-