Package com.safetykit.services.blocking
Class StreamServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.safetykit.services.blocking.StreamService.WithRawResponse
public final class StreamServiceImpl.WithRawResponseImpl implements StreamService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description StreamService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<StreamAddResponse>add(StreamAddParams params, RequestOptions requestOptions)HttpResponseFor<StreamAddFrameResponse>addFrame(StreamAddFrameParams params, RequestOptions requestOptions)HttpResponseFor<StreamAddTranscriptResponse>addTranscript(StreamAddTranscriptParams params, RequestOptions requestOptions)-
Methods inherited from class com.safetykit.services.blocking.StreamService.WithRawResponse
add, add, add, addFrame, addFrame, addFrame, addTranscript, addTranscript, addTranscript -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
StreamService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
add
HttpResponseFor<StreamAddResponse> add(StreamAddParams params, RequestOptions requestOptions)
-
addFrame
HttpResponseFor<StreamAddFrameResponse> addFrame(StreamAddFrameParams params, RequestOptions requestOptions)
-
addTranscript
HttpResponseFor<StreamAddTranscriptResponse> addTranscript(StreamAddTranscriptParams params, RequestOptions requestOptions)
-
-
-
-