Package com.safetykit.services.blocking
See: Description
-
Interface Summary Interface Description WithRawResponse A view of AgentDecisionService that provides access to raw HTTP responses for each method. AgentDecisionService Send human reviewer final verdicts to SafetyKit. WithRawResponse A view of ClientSessionService that provides access to raw HTTP responses for each method. ClientSessionService Create browser-safe webapp SDK session tokens from authenticated server-side code. WithRawResponse A view of DataService that provides access to raw HTTP responses for each method. DataService Ingest data for fraud detection and risk analysis. WithRawResponse A view of EventService that provides access to raw HTTP responses for each method. EventService Ingest server-side product and trust-and-safety events for fraud detection and risk analysis. WithRawResponse A view of StreamService that provides access to raw HTTP responses for each method. StreamService Ingest and monitor livestream content. -
Class Summary Class Description WithRawResponseImpl AgentDecisionServiceImpl Send human reviewer final verdicts to SafetyKit. WithRawResponseImpl ClientSessionServiceImpl Create browser-safe webapp SDK session tokens from authenticated server-side code. WithRawResponseImpl DataServiceImpl Ingest data for fraud detection and risk analysis. WithRawResponseImpl EventServiceImpl Ingest server-side product and trust-and-safety events for fraud detection and risk analysis. WithRawResponseImpl StreamServiceImpl Ingest and monitor livestream content.