Class SafetykitClientImpl
-
- All Implemented Interfaces:
-
com.safetykit.client.SafetykitClient
public final class SafetykitClientImpl implements SafetykitClient
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSafetykitClientImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description SafetykitClientImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description SafetykitClientAsyncasync()Returns a version of this client that uses asynchronous execution. SafetykitClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SafetykitClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DataServicedata()Ingest data for fraud detection and risk analysis. StreamServicestreams()Ingest and monitor livestream content. AgentDecisionServiceagentDecisions()Send human reviewer final verdicts to SafetyKit. EventServiceevents()Ingest server-side product and trust-and-safety events for fraud detection and risk analysis. ClientSessionServiceclientSessions()Create browser-safe webapp SDK session tokens from authenticated server-side code. Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
SafetykitClientImpl
SafetykitClientImpl(ClientOptions clientOptions)
-
-
Method Detail
-
async
SafetykitClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
SafetykitClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SafetykitClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
data
DataService data()
Ingest data for fraud detection and risk analysis.
-
streams
StreamService streams()
Ingest and monitor livestream content.
-
agentDecisions
AgentDecisionService agentDecisions()
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
events
EventService events()
Ingest server-side product and trust-and-safety events for fraud detection and risk analysis.
-
clientSessions
ClientSessionService clientSessions()
Create browser-safe webapp SDK session tokens from authenticated server-side code.
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-