Package com.safetykit.client
Class SafetykitClientImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.safetykit.client.SafetykitClient.WithRawResponse
public final class SafetykitClientImpl.WithRawResponseImpl implements SafetykitClient.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SafetykitClient.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DataService.WithRawResponsedata()Ingest data for fraud detection and risk analysis. StreamService.WithRawResponsestreams()Ingest and monitor livestream content. AgentDecisionService.WithRawResponseagentDecisions()Send human reviewer final verdicts to SafetyKit. -
-
Method Detail
-
withOptions
SafetykitClient.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
data
DataService.WithRawResponse data()
Ingest data for fraud detection and risk analysis.
-
streams
StreamService.WithRawResponse streams()
Ingest and monitor livestream content.
-
agentDecisions
AgentDecisionService.WithRawResponse agentDecisions()
Send human reviewer final verdicts to SafetyKit. This feedback improves the accuracy of SafetyKit's automated decisions over time.
-
-
-
-