Class DataCreateUploadUrlParams.Body
-
- All Implemented Interfaces:
public final class DataCreateUploadUrlParams.BodyRequest an upload URL for large JSONL batches. Send an empty JSON object if the namespace schema has already been configured, or include
schemato create or replace the namespace schema before upload.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataCreateUploadUrlParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<DataCreateUploadUrlParams.Schema>schema()Schema mapping field names to their definitions. final JsonField<DataCreateUploadUrlParams.Schema>_schema()Returns the raw JSON value of schema. final Map<String, JsonValue>_additionalProperties()final DataCreateUploadUrlParams.Body.BuildertoBuilder()final DataCreateUploadUrlParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataCreateUploadUrlParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
schema
final Optional<DataCreateUploadUrlParams.Schema> schema()
Schema mapping field names to their definitions. Use content_type to specify which fields contain URLs that should be processed (images, videos, or websites), datetime fields, or 'metadata' for fields that should be stored but not indexed. Use display_hint to provide UI rendering hints.
-
_schema
final JsonField<DataCreateUploadUrlParams.Schema> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataCreateUploadUrlParams.Body.Builder toBuilder()
-
validate
final DataCreateUploadUrlParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataCreateUploadUrlParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-