Class StreamAddTranscriptParams
-
- All Implemented Interfaces:
-
com.safetykit.core.Params
public final class StreamAddTranscriptParams implements Params
Ingest a single transcript segment for a livestream using a relative timestamp in milliseconds. The stream does not need to be created beforehand. Transcript timestamps are relative milliseconds from stream start and should be monotonically increasing within a stream so transcript context lines up correctly with later frames. This method returns immediately after the transcript has been accepted for processing.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStreamAddTranscriptParams.BuilderA builder for StreamAddTranscriptParams.
public final classStreamAddTranscriptParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>namespace()The namespace to ingest stream data into final StringstreamId()final Stringtext()final Longtimestamp()final JsonField<String>_streamId()Returns the raw JSON value of streamId. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<Long>_timestamp()Returns the raw JSON value of timestamp. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final StreamAddTranscriptParams.BuildertoBuilder()final StreamAddTranscriptParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static StreamAddTranscriptParams.Builderbuilder()Returns a mutable builder for constructing an instance of StreamAddTranscriptParams. -
-
Method Detail
-
_streamId
final JsonField<String> _streamId()
Returns the raw JSON value of streamId.
Unlike streamId, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<Long> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final StreamAddTranscriptParams.Builder toBuilder()
-
_body
final StreamAddTranscriptParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static StreamAddTranscriptParams.Builder builder()
Returns a mutable builder for constructing an instance of StreamAddTranscriptParams.
The following fields are required:
.streamId() .text() .timestamp()
-
-
-
-